@@ -130,12 +130,23 @@ describe ::AsciidoctorExtensions::KrokiBlockProcessor do
 </div>)
     end
   end
+  context 'instantiate' do
+    it 'should instantiate block processor without warning' do
+      original_stderr = $stderr
+      $stderr = StringIO.new
+      ::AsciidoctorExtensions::KrokiBlockProcessor.new 'plantuml'.to_sym, {}
+      output = $stderr.string
+      (expect output).to eql ''
+    ensure
+      $stderr = original_stderr
+    end
+  end
 end
 
 describe ::AsciidoctorExtensions::Kroki do
   it 'should return the list of supported diagrams' do
     diagram_names = ::AsciidoctorExtensions::Kroki::SUPPORTED_DIAGRAM_NAMES
-    expect(diagram_names).to include('vegalite', 'plantuml', 'bytefield', 'bpmn', 'excalidraw', 'wavedrom')
+    expect(diagram_names).to include('vegalite', 'plantuml', 'bytefield', 'bpmn', 'excalidraw', 'wavedrom', 'pikchr')
   end
   it 'should register the extension for the list of supported diagrams' do
     doc = Asciidoctor::Document.new
